==> nomachine-8.9.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/NXKeyadd.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXKeyadd::BEGIN{package NXKeyadd;no warnings;require POSIX;do{()};}package 
NXKeyadd;no warnings;$clientPublicKey;sub getClientPublicKey{return (
$clientPublicKey);}sub setClientPublicKey{($clientPublicKey=shift (@_));
Logger::debug (((
"\x53\x65\x74\x74\x69\x6e\x67\x20\x63\x6c\x69\x65\x6e\x74\x20\x70\x75\x62\x6c\x69\x63\x20\x6b\x65\x79\x20\x5b"
.$clientPublicKey)."\x5d"));}sub runKeyAdd{(my $line=shift (@_));Logger::debug (
(("\x72\x75\x6e\x4b\x65\x79\x41\x64\x64\x20\x6c\x69\x6e\x65\x20\x5b".$line).
"\x5d"));main::parse_arguments ($line);(my $key=$GLOBAL::parameters{
"\x6b\x65\x79"});if (($GLOBAL::parameters{"\x70\x72\x6f\x74\x6f\x63\x6f\x6c"}eq 
(""))){($GLOBAL::parameters{"\x70\x72\x6f\x74\x6f\x63\x6f\x6c"}="\x4e\x58");}
Logger::debug ((((("\x6b\x65\x79\x20\x5b".$GLOBAL::parameters{"\x6b\x65\x79"}).
"\x5d\x20\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x20\x5b").$GLOBAL::parameters{
"\x70\x72\x6f\x74\x6f\x63\x6f\x6c"})."\x5d"));(my (@options)=());my (
$nxserverPid);push (@options,"\x67\x65\x74\x20\x70\x69\x64",(\$nxserverPid));my (
$socketServer);main::nxrequire (
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65");
NXConsole::createConsole ();(my $slaveIN=NXConsole::getConsoleChildIN ());(my $slaveOUT
=NXConsole::getConsoleChildOUT ());(my $socketServer=
NXConsole::getConsoleDescriptor ());Logger::debug ((((((("\x70\x74\x79\x20\x5b".
$socketServer).
"\x5d\x20\x73\x6c\x61\x76\x65\x20\x70\x74\x79\x20\x49\x4e\x2f\x4f\x55\x54\x20\x5b"
).$slaveIN)."\x2f").$slaveOUT)."\x5d\x2e"));push (@options,
"\x75\x73\x65\x20\x61\x73\x20\x73\x74\x64\x69\x6e",$slaveIN);push (@options,
"\x75\x73\x65\x20\x61\x73\x20\x73\x74\x64\x6f\x75\x74",$slaveOUT);push (@options
,"\x45\x52\x52\x69\x6e\x4f\x55\x54");push (@options,
"\x63\x6c\x6f\x73\x65\x41\x66\x74\x65\x72\x52\x75\x6e",$slaveIN);push (@options,
"\x6c\x65\x61\x76\x65\x20\x73\x74\x64\x69\x6e\x20\x6f\x70\x65\x6e");push (
@options,"\x6c\x65\x61\x76\x65\x20\x73\x74\x64\x6f\x75\x74\x20\x6f\x70\x65\x6e")
;Common::NXCore::cleanOutLanguageCasesInEnvironemt ();push (@options,
"\x66\x75\x6c\x6c\x20\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74");push (
@options,"\x72\x75\x6e\x20\x69\x6e\x20\x62\x67");(my (@command)=());if (($>==
(0x04ec+ 3696-0x135c))){Logger::debug (
"\x45\x66\x66\x65\x63\x74\x69\x76\x65\x20\x75\x73\x65\x72\x20\x69\x73\x20\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x2c\x20\x73\x6b\x69\x70\x20\x27\x73\x75\x64\x6f\x27\x2e"
);}else{(my $commandSudo=Common::NXShellCommands::checkPath ("\x73\x75\x64\x6f")
);push (@command,$commandSudo,"\x2d\x53");push (@options,
"\x75\x73\x65\x20\x73\x63\x72\x69\x70\x74\x20\x74\x6f\x20\x6b\x69\x6c\x6c");}
push (@command,
"\x2f\x65\x74\x63\x2f\x4e\x58\x2f\x6e\x78\x73\x65\x72\x76\x65\x72");push (
@command,"\x2d\x2d\x6b\x65\x79\x61\x64\x64");push (@command,
"\x2d\x2d\x70\x61\x63\x6b\x65\x64\x2d\x6d\x65\x73\x73\x61\x67\x65\x73",
(0x101d+ 5850-0x26f6));main::nxRunCommand ((\@command),(\@options));(my $selector
="\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x53\x65\x6c\x65\x63\x74\x6f\x72"->new
);(my $signalFd=$$NXBegin::parser{"\x53\x69\x67\x6e\x61\x6c"});$selector->add (
$signalFd);$selector->add ($socketServer);$selector->add (main::nxgetSTDIN ());my (
$read_buf);my ($bytes_read);(my $pwdalreadysent=(0x1c06+ 1255-0x20ed));while ((my (
@ready)=$selector->can_read)){Logger::debug (((
"\x63\x61\x6e\x5f\x72\x65\x61\x64\x20\x5b".join ($",@ready))."\x5d"));foreach my $fh
 (@ready){Logger::debug ((("\x43\x68\x65\x63\x6b\x69\x6e\x67\x20\x5b".$fh).
"\x5d"));if (($fh==$socketServer)){($bytes_read=main::nxread ($fh,(\$read_buf),
(0x1e9a+ 5284-0x233e)));Logger::debug (((((
"\x52\x65\x61\x64\x20\x66\x72\x6f\x6d\x20\x6e\x78\x73\x65\x72\x76\x65\x72\x20\x2d\x2d\x6b\x65\x79\x61\x64\x64\x20\x5b"
.$read_buf)."\x5d\x20\x5b").$bytes_read)."\x5d"));if ((($bytes_read eq 
(0x0a88+ 1925-0x120d))or (not (defined ($bytes_read))))){Logger::debug (
"\x4e\x6f\x74\x68\x69\x6e\x67\x20\x74\x6f\x20\x72\x65\x61\x64\x20\x66\x72\x6f\x6d\x20\x6e\x78\x73\x65\x72\x76\x65\x72\x20\x2d\x2d\x6b\x65\x79\x61\x64\x64\x2e"
);$selector->remove ($fh);$selector->remove ($signalFd);return (
(0x0d7b+ 6240-0x25db));}chomp ($read_buf);($read_buf=~ s/\015//gs );($read_buf=~ s/^\n//gs )
;Logger::debug (((((
"\x46\x69\x6c\x74\x65\x72\x65\x64\x20\x6d\x65\x73\x73\x61\x67\x65\x20\x5b".
$read_buf)."\x5d\x20\x5b").$bytes_read)."\x5d"));($bytes_read=length ($read_buf)
);if (Common::NXShellCommands::isNotInSudoersMessage ($read_buf)){(my $error=
"\x55\x73\x65\x72\x20\x69\x73\x20\x6e\x6f\x74\x20\x69\x6e\x20\x73\x75\x64\x6f\x65\x72\x73\x20\x66\x69\x6c\x65\x2e"
);Logger::warning ($error);(my $message=(((("\x4e\x58\x3e\x20".
$GLOBAL::MSG_ERROR_NOT_SUDOERS)."\x20\x65\x72\x72\x6f\x72\x3d").main::urlencode 
($error))."\x20\x0a"));main::nxwrite (main::nxgetSTDOUT (),$message);$selector->
remove ($socketServer);$selector->remove ($signalFd);if ($selector->exists (
main::nxgetSTDIN ())){$selector->remove (main::nxgetSTDIN ());}}elsif (
Common::NXShellCommands::isNotAdministrator ($read_buf)){(my $error=
"\x55\x73\x65\x72\x20\x69\x73\x20\x6e\x6f\x74\x20\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x2e"
);Logger::warning ($error);(my $message=(((("\x4e\x58\x3e\x20".
$GLOBAL::MSG_ERROR_NOT_ADMINISTRATOR)."\x20\x65\x72\x72\x6f\x72\x3d").
main::urlencode ($error))."\x20\x0a"));main::nxwrite (main::nxgetSTDOUT (),
$message);$selector->remove ($socketServer);$selector->remove ($signalFd);if (
$selector->exists (main::nxgetSTDIN ())){$selector->remove (main::nxgetSTDIN ())
;}}elsif (Common::NXShellCommands::isPasswordRequestMessage ($read_buf)){if ((
$pwdalreadysent==(0x1765+ 2933-0x22da))){(my $message=(("\x4e\x58\x3e\x20".
$GLOBAL::MSG_ASK_FOR_PASSWORD)."\x20\x0a"));(my $writtenbytes=main::nxwrite (
main::nxgetSTDOUT (),$message));Logger::debug (((((
"\x41\x73\x6b\x69\x6e\x67\x20\x66\x6f\x72\x20\x73\x75\x64\x6f\x20\x70\x61\x73\x73\x77\x6f\x72\x64\x20\x5b"
.$message)."\x5d\x20\x5b").$writtenbytes)."\x5d"));($pwdalreadysent=
(0x04a0+ 8683-0x268a));}else{(my $bytes=main::nxwrite ($socketServer,
"\x0a\x0a\x0a"));Logger::debug (((
"\x53\x65\x6e\x64\x69\x6e\x67\x20\x65\x6d\x70\x74\x79\x20\x70\x61\x73\x73\x77\x6f\x72\x64\x20\x5b"
.$bytes)."\x5d"));(my $error=
"\x53\x75\x64\x6f\x20\x70\x61\x73\x73\x77\x6f\x72\x64\x20\x64\x6f\x65\x73\x20\x6e\x6f\x74\x20\x6d\x61\x74\x63\x68"
);Logger::warning ($error);(my $message=(((("\x4e\x58\x3e\x20".
$GLOBAL::MSG_ERROR_SUDO_PASS_NOT_MATCH)."\x20\x65\x72\x72\x6f\x72\x3d").
main::urlencode ($error))."\x20\x0a"));main::nxwrite (main::nxgetSTDOUT (),
$message);}}elsif (($read_buf=~ /NX> $GLOBAL::MSG_NODE_ERROR_INITIALIZATION / ))
{(my $message=("\x4e\x58\x3e\x20\x70\x61\x72\x61\x6d\x73\x3d\x6b\x65\x79\x3d".
main::urlencode ($GLOBAL::parameters{"\x6b\x65\x79"})));($message.=(
"\x26\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x3d".$GLOBAL::parameters{
"\x70\x72\x6f\x74\x6f\x63\x6f\x6c"}));($message.=(("\x26\x75\x75\x69\x64\x3d".
$GLOBAL::parameters{"\x75\x75\x69\x64"})."\x20"));(my $bytes=main::nxwrite (
$socketServer,($message."\x0a")));Logger::debug (((((
"\x53\x65\x6e\x64\x69\x6e\x67\x20\x6b\x65\x79\x20\x74\x6f\x20\x6e\x78\x73\x65\x72\x76\x65\x72\x20\x2d\x2d\x6b\x65\x79\x61\x64\x64\x20\x5b"
.$message)."\x5d\x20\x5b").$bytes)."\x5d"));}elsif (($read_buf=~ /NX> $GLOBAL::MSG_KEY_ADDED / )
){(my $bytes=main::nxwrite (main::nxgetSTDOUT (),($read_buf."\x0a")));
Logger::debug (((((
"\x4b\x65\x79\x20\x61\x64\x64\x65\x64\x20\x63\x6f\x72\x72\x65\x63\x74\x6c\x79\x2e\x20\x5b"
.$read_buf)."\x5d\x20\x5b").$bytes)."\x5d"));$selector->remove ($socketServer);
$selector->remove ($signalFd);if ($selector->exists (main::nxgetSTDIN ())){
$selector->remove (main::nxgetSTDIN ());}}elsif (Common::NXMsg::isPackedMessage 
($read_buf)){(my $bytes=main::nxwrite (main::nxgetSTDOUT (),($read_buf."\x0a")))
;Logger::debug (((((
"\x50\x61\x73\x73\x69\x6e\x67\x20\x70\x61\x63\x6b\x65\x64\x20\x6d\x65\x73\x73\x61\x67\x65\x20\x74\x6f\x20\x6e\x78\x73\x65\x72\x76\x65\x72\x20\x5b"
.$read_buf)."\x5d\x20\x5b").$bytes)."\x5d"));$selector->remove ($socketServer);
$selector->remove ($signalFd);if ($selector->exists (main::nxgetSTDIN ())){
$selector->remove (main::nxgetSTDIN ());}}}elsif (($fh==main::nxgetSTDIN ())){my (
$read_buf);(my $bytes_read=main::nxread ($fh,(\$read_buf),(0x1b08+ 5855-0x21e7))
);if (($bytes_read==(0x145b+ 2144-0x1cbb))){Logger::debug (
"\x52\x65\x6d\x6f\x76\x65\x20\x53\x54\x44\x49\x4e\x2e");$selector->remove ($fh);
}elsif (($read_buf=~ /NX> $GLOBAL::MSG_PASSWORD_ANSWER password=(.*) / )){(my $password
=$1);(my $bytes=main::nxwrite ($socketServer,($password."\x0a\x0a\x0a")));
Logger::debug (((
"\x53\x65\x6e\x64\x69\x6e\x67\x20\x70\x61\x73\x73\x77\x6f\x72\x64\x20\x74\x6f\x20\x73\x75\x64\x6f\x20\x5b"
.$bytes)."\x5d"));$selector->remove (main::nxgetSTDIN ());}}}}
handleProcessAfterFinish ($nxserverPid);}sub handleProcessAfterFinish{(my $pid=
shift (@_));Common::NXProcess::waitToTerminateOrKillByScriptIfStayAlive ($pid,
(0x13a9+ 2349-0x1cd1));}"\x3f\x3f\x3f";

==> nomachine-8.10.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/NXKeyadd.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXKeyadd::BEGIN{package NXKeyadd;no warnings;require POSIX;do{()};}package 
NXKeyadd;no warnings;$clientPublicKey;sub getClientPublicKey{return (
$clientPublicKey);}sub setClientPublicKey{($clientPublicKey=shift (@_));
Logger::debug (((
"\x53\x65\x74\x74\x69\x6e\x67\x20\x63\x6c\x69\x65\x6e\x74\x20\x70\x75\x62\x6c\x69\x63\x20\x6b\x65\x79\x20\x5b"
.$clientPublicKey)."\x5d"));}sub runKeyAdd{(my $line=shift (@_));Logger::debug (
(("\x72\x75\x6e\x4b\x65\x79\x41\x64\x64\x20\x6c\x69\x6e\x65\x20\x5b".$line).
"\x5d"));main::parse_arguments ($line);(my $key=$GLOBAL::parameters{
"\x6b\x65\x79"});if (($GLOBAL::parameters{"\x70\x72\x6f\x74\x6f\x63\x6f\x6c"}eq 
(""))){($GLOBAL::parameters{"\x70\x72\x6f\x74\x6f\x63\x6f\x6c"}="\x4e\x58");}
Logger::debug ((((("\x6b\x65\x79\x20\x5b".$GLOBAL::parameters{"\x6b\x65\x79"}).
"\x5d\x20\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x20\x5b").$GLOBAL::parameters{
"\x70\x72\x6f\x74\x6f\x63\x6f\x6c"})."\x5d"));(my (@options)=());my (
$nxserverPid);push (@options,"\x67\x65\x74\x20\x70\x69\x64",(\$nxserverPid));my (
$socketServer);main::nxrequire (
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65");
NXConsole::createConsole ();(my $slaveIN=NXConsole::getConsoleChildIN ());(my $slaveOUT
=NXConsole::getConsoleChildOUT ());(my $socketServer=
NXConsole::getConsoleDescriptor ());Logger::debug ((((((("\x70\x74\x79\x20\x5b".
$socketServer).
"\x5d\x20\x73\x6c\x61\x76\x65\x20\x70\x74\x79\x20\x49\x4e\x2f\x4f\x55\x54\x20\x5b"
).$slaveIN)."\x2f").$slaveOUT)."\x5d\x2e"));push (@options,
"\x75\x73\x65\x20\x61\x73\x20\x73\x74\x64\x69\x6e",$slaveIN);push (@options,
"\x75\x73\x65\x20\x61\x73\x20\x73\x74\x64\x6f\x75\x74",$slaveOUT);push (@options
,"\x45\x52\x52\x69\x6e\x4f\x55\x54");push (@options,
"\x63\x6c\x6f\x73\x65\x41\x66\x74\x65\x72\x52\x75\x6e",$slaveIN);push (@options,
"\x6c\x65\x61\x76\x65\x20\x73\x74\x64\x69\x6e\x20\x6f\x70\x65\x6e");push (
@options,"\x6c\x65\x61\x76\x65\x20\x73\x74\x64\x6f\x75\x74\x20\x6f\x70\x65\x6e")
;Common::NXCore::cleanOutLanguageCasesInEnvironemt ();push (@options,
"\x66\x75\x6c\x6c\x20\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74");push (
@options,"\x72\x75\x6e\x20\x69\x6e\x20\x62\x67");(my (@command)=());if (($>==
(0x0f00+ 2397-0x185d))){Logger::debug (
"\x45\x66\x66\x65\x63\x74\x69\x76\x65\x20\x75\x73\x65\x72\x20\x69\x73\x20\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x2c\x20\x73\x6b\x69\x70\x20\x27\x73\x75\x64\x6f\x27\x2e"
);}else{(my $commandSudo=Common::NXShellCommands::checkPath ("\x73\x75\x64\x6f")
);push (@command,$commandSudo,"\x2d\x53");push (@options,
"\x75\x73\x65\x20\x73\x63\x72\x69\x70\x74\x20\x74\x6f\x20\x6b\x69\x6c\x6c");}
push (@command,
"\x2f\x65\x74\x63\x2f\x4e\x58\x2f\x6e\x78\x73\x65\x72\x76\x65\x72");push (
@command,"\x2d\x2d\x6b\x65\x79\x61\x64\x64");push (@command,
"\x2d\x2d\x70\x61\x63\x6b\x65\x64\x2d\x6d\x65\x73\x73\x61\x67\x65\x73",
(0x0412+ 7066-0x1fab));main::nxRunCommand ((\@command),(\@options));(my $selector
="\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x53\x65\x6c\x65\x63\x74\x6f\x72"->new
);(my $signalFd=$$NXBegin::parser{"\x53\x69\x67\x6e\x61\x6c"});$selector->add (
$signalFd);$selector->add ($socketServer);$selector->add (main::nxgetSTDIN ());my (
$read_buf);my ($bytes_read);(my $pwdalreadysent=(0x0e62+ 3880-0x1d8a));while ((my (
@ready)=$selector->can_read)){Logger::debug (((
"\x63\x61\x6e\x5f\x72\x65\x61\x64\x20\x5b".join ($",@ready))."\x5d"));foreach my $fh
 (@ready){Logger::debug ((("\x43\x68\x65\x63\x6b\x69\x6e\x67\x20\x5b".$fh).
"\x5d"));if (($fh==$socketServer)){($bytes_read=main::nxread ($fh,(\$read_buf),
4096));Logger::debug (((((
"\x52\x65\x61\x64\x20\x66\x72\x6f\x6d\x20\x6e\x78\x73\x65\x72\x76\x65\x72\x20\x2d\x2d\x6b\x65\x79\x61\x64\x64\x20\x5b"
.$read_buf)."\x5d\x20\x5b").$bytes_read)."\x5d"));if ((($bytes_read eq 
(0x0130+ 4194-0x1192))or (not (defined ($bytes_read))))){Logger::debug (
"\x4e\x6f\x74\x68\x69\x6e\x67\x20\x74\x6f\x20\x72\x65\x61\x64\x20\x66\x72\x6f\x6d\x20\x6e\x78\x73\x65\x72\x76\x65\x72\x20\x2d\x2d\x6b\x65\x79\x61\x64\x64\x2e"
);$selector->remove ($fh);$selector->remove ($signalFd);return (
(0x045b+ 6683-0x1e76));}chomp ($read_buf);($read_buf=~ s/\015//gs );($read_buf=~ s/^\n//gs )
;Logger::debug (((((
"\x46\x69\x6c\x74\x65\x72\x65\x64\x20\x6d\x65\x73\x73\x61\x67\x65\x20\x5b".
$read_buf)."\x5d\x20\x5b").$bytes_read)."\x5d"));($bytes_read=length ($read_buf)
);if (Common::NXShellCommands::isNotInSudoersMessage ($read_buf)){(my $error=
"\x55\x73\x65\x72\x20\x69\x73\x20\x6e\x6f\x74\x20\x69\x6e\x20\x73\x75\x64\x6f\x65\x72\x73\x20\x66\x69\x6c\x65\x2e"
);Logger::warning ($error);(my $message=(((("\x4e\x58\x3e\x20".
$GLOBAL::MSG_ERROR_NOT_SUDOERS)."\x20\x65\x72\x72\x6f\x72\x3d").main::urlencode 
($error))."\x20\x0a"));main::nxwrite (main::nxgetSTDOUT (),$message);$selector->
remove ($socketServer);$selector->remove ($signalFd);if ($selector->exists (
main::nxgetSTDIN ())){$selector->remove (main::nxgetSTDIN ());}}elsif (
Common::NXShellCommands::isNotAdministrator ($read_buf)){(my $error=
"\x55\x73\x65\x72\x20\x69\x73\x20\x6e\x6f\x74\x20\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x2e"
);Logger::warning ($error);(my $message=(((("\x4e\x58\x3e\x20".
$GLOBAL::MSG_ERROR_NOT_ADMINISTRATOR)."\x20\x65\x72\x72\x6f\x72\x3d").
main::urlencode ($error))."\x20\x0a"));main::nxwrite (main::nxgetSTDOUT (),
$message);$selector->remove ($socketServer);$selector->remove ($signalFd);if (
$selector->exists (main::nxgetSTDIN ())){$selector->remove (main::nxgetSTDIN ())
;}}elsif (Common::NXShellCommands::isPasswordRequestMessage ($read_buf)){if ((
$pwdalreadysent==(0x2129+ 943-0x24d8))){(my $message=(("\x4e\x58\x3e\x20".
$GLOBAL::MSG_ASK_FOR_PASSWORD)."\x20\x0a"));(my $writtenbytes=main::nxwrite (
main::nxgetSTDOUT (),$message));Logger::debug (((((
"\x41\x73\x6b\x69\x6e\x67\x20\x66\x6f\x72\x20\x73\x75\x64\x6f\x20\x70\x61\x73\x73\x77\x6f\x72\x64\x20\x5b"
.$message)."\x5d\x20\x5b").$writtenbytes)."\x5d"));($pwdalreadysent=
(0x0012+ 7904-0x1ef1));}else{(my $bytes=main::nxwrite ($socketServer,
"\x0a\x0a\x0a"));Logger::debug (((
"\x53\x65\x6e\x64\x69\x6e\x67\x20\x65\x6d\x70\x74\x79\x20\x70\x61\x73\x73\x77\x6f\x72\x64\x20\x5b"
.$bytes)."\x5d"));(my $error=
"\x53\x75\x64\x6f\x20\x70\x61\x73\x73\x77\x6f\x72\x64\x20\x64\x6f\x65\x73\x20\x6e\x6f\x74\x20\x6d\x61\x74\x63\x68"
);Logger::warning ($error);(my $message=(((("\x4e\x58\x3e\x20".
$GLOBAL::MSG_ERROR_SUDO_PASS_NOT_MATCH)."\x20\x65\x72\x72\x6f\x72\x3d").
main::urlencode ($error))."\x20\x0a"));main::nxwrite (main::nxgetSTDOUT (),
$message);}}elsif (($read_buf=~ /NX> $GLOBAL::MSG_NODE_ERROR_INITIALIZATION / ))
{(my $message=("\x4e\x58\x3e\x20\x70\x61\x72\x61\x6d\x73\x3d\x6b\x65\x79\x3d".
main::urlencode ($GLOBAL::parameters{"\x6b\x65\x79"})));($message.=(
"\x26\x70\x72\x6f\x74\x6f\x63\x6f\x6c\x3d".$GLOBAL::parameters{
"\x70\x72\x6f\x74\x6f\x63\x6f\x6c"}));($message.=(("\x26\x75\x75\x69\x64\x3d".
$GLOBAL::parameters{"\x75\x75\x69\x64"})."\x20"));(my $bytes=main::nxwrite (
$socketServer,($message."\x0a")));Logger::debug (((((
"\x53\x65\x6e\x64\x69\x6e\x67\x20\x6b\x65\x79\x20\x74\x6f\x20\x6e\x78\x73\x65\x72\x76\x65\x72\x20\x2d\x2d\x6b\x65\x79\x61\x64\x64\x20\x5b"
.$message)."\x5d\x20\x5b").$bytes)."\x5d"));}elsif (($read_buf=~ /NX> $GLOBAL::MSG_KEY_ADDED / )
){(my $bytes=main::nxwrite (main::nxgetSTDOUT (),($read_buf."\x0a")));
Logger::debug (((((
"\x4b\x65\x79\x20\x61\x64\x64\x65\x64\x20\x63\x6f\x72\x72\x65\x63\x74\x6c\x79\x2e\x20\x5b"
.$read_buf)."\x5d\x20\x5b").$bytes)."\x5d"));$selector->remove ($socketServer);
$selector->remove ($signalFd);if ($selector->exists (main::nxgetSTDIN ())){
$selector->remove (main::nxgetSTDIN ());}}elsif (Common::NXMsg::isPackedMessage 
($read_buf)){(my $bytes=main::nxwrite (main::nxgetSTDOUT (),($read_buf."\x0a")))
;Logger::debug (((((
"\x50\x61\x73\x73\x69\x6e\x67\x20\x70\x61\x63\x6b\x65\x64\x20\x6d\x65\x73\x73\x61\x67\x65\x20\x74\x6f\x20\x6e\x78\x73\x65\x72\x76\x65\x72\x20\x5b"
.$read_buf)."\x5d\x20\x5b").$bytes)."\x5d"));$selector->remove ($socketServer);
$selector->remove ($signalFd);if ($selector->exists (main::nxgetSTDIN ())){
$selector->remove (main::nxgetSTDIN ());}}}elsif (($fh==main::nxgetSTDIN ())){my (
$read_buf);(my $bytes_read=main::nxread ($fh,(\$read_buf),(0x1da7+ 1780-0x149b))
);if (($bytes_read==(0x06e7+ 3106-0x1309))){Logger::debug (
"\x52\x65\x6d\x6f\x76\x65\x20\x53\x54\x44\x49\x4e\x2e");$selector->remove ($fh);
}elsif (($read_buf=~ /NX> $GLOBAL::MSG_PASSWORD_ANSWER password=(.*) / )){(my $password
=$1);(my $bytes=main::nxwrite ($socketServer,($password."\x0a\x0a\x0a")));
Logger::debug (((
"\x53\x65\x6e\x64\x69\x6e\x67\x20\x70\x61\x73\x73\x77\x6f\x72\x64\x20\x74\x6f\x20\x73\x75\x64\x6f\x20\x5b"
.$bytes)."\x5d"));$selector->remove (main::nxgetSTDIN ());}}}}
handleProcessAfterFinish ($nxserverPid);}sub handleProcessAfterFinish{(my $pid=
shift (@_));Common::NXProcess::waitToTerminateOrKillByScriptIfStayAlive ($pid,
(0x1427+ 3906-0x2364));}"\x3f\x3f\x3f";
